## Today
- version自动编号增加

### Features
X 记录shell历史记录到文件
X shell自由编辑模式（F12）

### Fix
- 快速创建快捷方式（context_helper.pyw）
- 兼容py34
- 修复自动括号匹配的使用体验
- 内建搜索窗口不置顶
- 比较选中的文本和剪切板内容（CompareFile.py）


## TODO NOTE
- 选中两个文件右键交换文件名
